'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.logout = exports.LOGOUT_REJECTED = exports.LOGOUT_FULFILLED = exports.LOGOUT_STARTED = exports.login = exports.LOGIN_REJECTED = exports.LOGIN_FULFILLED = exports.LOGIN_STARTED = exports.resetLogin = exports.RESET_LOGIN = exports.redirectLogin = exports.LOGIN_REDIRECTED = exports.configureCSpace = exports.CSPACE_CONFIGURED = undefined;

var _cspaceClient = require('cspace-client');

var _cspaceClient2 = _interopRequireDefault(_cspaceClient);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var cspace = void 0;
var session = void 0;

var CSPACE_CONFIGURED = exports.CSPACE_CONFIGURED = 'CSPACE_CONFIGURED';

var configureCSpace = exports.configureCSpace = function configureCSpace(config) {
  cspace = (0, _cspaceClient2.default)(config);
  session = cspace.session();

  return {
    type: CSPACE_CONFIGURED,
    payload: session.config()
  };
};

var LOGIN_REDIRECTED = exports.LOGIN_REDIRECTED = 'LOGIN_REDIRECTED';

var redirectLogin = exports.redirectLogin = function redirectLogin(replace, attemptedUrl) {
  return function (dispatch) {
    replace('/login');

    dispatch({
      type: LOGIN_REDIRECTED,
      meta: {
        attemptedUrl: attemptedUrl
      }
    });
  };
};

var RESET_LOGIN = exports.RESET_LOGIN = 'RESET_LOGIN';

var resetLogin = exports.resetLogin = function resetLogin() {
  return function (dispatch) {
    return dispatch({
      type: RESET_LOGIN
    });
  };
};

var LOGIN_STARTED = exports.LOGIN_STARTED = 'LOGIN_STARTED';
var LOGIN_FULFILLED = exports.LOGIN_FULFILLED = 'LOGIN_FULFILLED';
var LOGIN_REJECTED = exports.LOGIN_REJECTED = 'LOGIN_REJECTED';

var login = exports.login = function login(username, password) {
  return function (dispatch) {
    dispatch({
      type: LOGIN_STARTED,
      meta: {
        username: username
      }
    });

    session = cspace.session({
      username: username,
      password: password
    });

    session.login().then(function (response) {
      return dispatch({
        type: LOGIN_FULFILLED,
        payload: response,
        meta: {
          username: username
        }
      });
    }).catch(function (error) {
      return dispatch({
        type: LOGIN_REJECTED,
        payload: error,
        meta: {
          username: username
        }
      });
    });
  };
};

var LOGOUT_STARTED = exports.LOGOUT_STARTED = 'LOGOUT_STARTED';
var LOGOUT_FULFILLED = exports.LOGOUT_FULFILLED = 'LOGOUT_FULFILLED';
var LOGOUT_REJECTED = exports.LOGOUT_REJECTED = 'LOGOUT_REJECTED';

var logout = exports.logout = function logout() {
  return function (dispatch) {
    dispatch({
      type: LOGOUT_STARTED
    });

    session.logout().then(function (response) {
      return dispatch({
        type: LOGOUT_FULFILLED,
        payload: response
      });
    }).catch(function (error) {
      return dispatch({
        type: LOGOUT_REJECTED,
        payload: error
      });
    });
  };
};